@@ -250,7 +250,7 @@ determine_prefix(const pkgconf_pkg_t *pkg, char *buf, size_t buflen)
 static char *
 convert_path_to_value(const char *path)
 {
-	char *buf = calloc((strlen(path) + 1) * 2, 1);
+	char *buf = calloc(1, (strlen(path) + 1) * 2);
 	char *bptr = buf;
 	const char *i;
 
@@ -419,7 +419,7 @@ pkgconf_pkg_new_from_file(pkgconf_client_t *client, const char *filename, FILE *
 	pkgconf_pkg_t *pkg;
 	char *idptr;
 
-	pkg = calloc(sizeof(pkgconf_pkg_t), 1);
+	pkg = calloc(1, sizeof(pkgconf_pkg_t));
 	pkg->owner = client;
 	pkg->filename = strdup(filename);
 	pkg->pc_filedir = pkg_get_parent_dir(pkg);
@@ -1417,7 +1417,7 @@ pkgconf_pkg_verify_dependency(pkgconf_client_t *client, pkgconf_dependency_t *pk
 			pkgdep->match = pkgconf_pkg_ref(client, pkg);
 	}
 
-	if (pkg != NULL)
+	if (pkg != NULL && pkg->why == NULL)
 		pkg->why = strdup(pkgdep->package);
 
 	return pkg;
@@ -1487,6 +1487,8 @@ pkgconf_pkg_walk_list(pkgconf_client_t *client,
 	unsigned int eflags = PKGCONF_PKG_ERRF_OK;
 	pkgconf_node_t *node, *next;
 
+	parent->flags |= PKGCONF_PKG_PKGF_ANCESTOR;
+
 	PKGCONF_FOREACH_LIST_ENTRY_SAFE(deplist->head, next, node)
 	{
 		unsigned int eflags_local = PKGCONF_PKG_ERRF_OK;
@@ -1507,7 +1509,7 @@ pkgconf_pkg_walk_list(pkgconf_client_t *client,
 		if (pkgdep == NULL)
 			continue;
 
-		if (pkgdep->serial == client->serial && !(parent->flags & PKGCONF_PKG_PROPF_VIRTUAL))
+		if((pkgdep->flags & PKGCONF_PKG_PKGF_ANCESTOR) != 0)
 		{
 			pkgdep->identifier = ++client->identifier;
 
@@ -1545,6 +1547,8 @@ next:
 		pkgconf_pkg_unref(client, pkgdep);
 	}
 
+	parent->flags &= ~PKGCONF_PKG_PKGF_ANCESTOR;
+
 	return eflags;
 }
 
